Use standard BLOB,KEY,NACK as contentType instead of customized types

Change-Id: I792e19b8f1e2aa359605da44074fc25bf7963a9a
diff --git a/tests/unit/daemon/name-server.cpp b/tests/unit/daemon/name-server.cpp
index 4b6af12..581f3e0 100644
--- a/tests/unit/daemon/name-server.cpp
+++ b/tests/unit/daemon/name-server.cpp
@@ -85,8 +85,6 @@
   BOOST_CHECK_EQUAL(hasDataBack, true);
 }
 
-BOOST_AUTO_TEST_CASE_EXPECTED_FAILURES(KeyQuery, 2)
-
 BOOST_AUTO_TEST_CASE(KeyQuery)
 {
   Query q(zone, ndns::label::NDNS_ITERATIVE_QUERY);
@@ -109,7 +107,7 @@
   face.receive(q.toInterest());
   run();
 
   // will ask for the existing record (will have type NDNS_BLOB, as it is certificate)
   face.onSendData.connectSingleShot([&] (const Data& data) {
     ++nDataBack;
     NDNS_LOG_TRACE("get Data back");
@@ -117,7 +115,7 @@
 
     Response resp;
     BOOST_CHECK_NO_THROW(resp.fromData(zone, data));
-    BOOST_CHECK_EQUAL(resp.getContentType(), NDNS_BLOB);
+    BOOST_CHECK_EQUAL(resp.getContentType(), NDNS_KEY);
   });
 
   q.setRrLabel("dsk-1");
@@ -135,7 +133,7 @@
 
     Response resp;
     BOOST_CHECK_NO_THROW(resp.fromData(zone, data));
-    BOOST_CHECK_EQUAL(resp.getContentType(), NDNS_BLOB);
+    BOOST_CHECK_EQUAL(resp.getContentType(), NDNS_KEY);
   });
 
   run();
@@ -109,7 +107,7 @@
   run();
 
-  // will ask for the existing record (will have type NDNS_BLOB, as it is certificate)
+  // will ask for the existing record (will have type NDNS_KEY, as it is certificate)
   face.onSendData.connectSingleShot([&] (const Data& data) {
     ++nDataBack;